==> owncloud-10.0.7.zip: owncloud/core/l10n/vi.js <==
OC.L10N.register(
    "core",
    {
    "No image or file provided" : "Không có hình ảnh hoặc tập tin được cung cấp",
    "Unknown filetype" : "Không biết kiểu tập tin",
    "Invalid image" : "Hình ảnh không hợp lệ",
    "No temporary profile picture available, try again" : "Ảnh cá nhân tạm thời không có giá trị, hãy thử lại",
    "No crop data provided" : "Không có dữ liệu nguồn được cung cấp",
    "%s password reset" : "%s thiết lập lại mật khẩu",
    "Couldn't send mail to following users: %s " : "Không thể gửi thư cho người dùng: %s",
    "Turned on maintenance mode" : "Bật chế độ bảo trì",
    "Turned off maintenance mode" : "Tắt chế độ bảo trì",
    "Updated database" : "Cơ sở dữ liệu đã được cập nhật",
    "Sunday" : "Chủ nhật",
    "Monday" : "Thứ 2",
    "Tuesday" : "Thứ 3",
    "Wednesday" : "Thứ 4",
    "Thursday" : "Thứ 5",
    "Friday" : "Thứ ",
    "Saturday" : "Thứ 7",
    "Sun." : "Chủ nhật",
    "Mon." : "Thứ hai",
    "Tue." : "Thứ ba",
    "Wed." : "Thứ tư",
    "Thu." : "Thứ năm",
    "Fri." : "Thứ sáu",
    "Sat." : "Thứ bảy",
    "January" : "Tháng 1",
    "February" : "Tháng 2",
    "March" : "Tháng 3",
    "April" : "Tháng 4",
    "May" : "Tháng 5",
    "June" : "Tháng 6",
    "July" : "Tháng 7",
    "August" : "Tháng 8",
    "September" : "Tháng 9",
    "October" : "Tháng 10",
    "November" : "Tháng 11",
    "December" : "Tháng 12",
    "Jan." : "Tháng 1",
    "Feb." : "Tháng 2",
    "Mar." : "Tháng 3",
    "Apr." : "Tháng 4",
    "May." : "Tháng 5",
    "Jun." : "Tháng 6",
    "Jul." : "Tháng 7",
    "Aug." : "Tháng 8",
    "Sep." : "Tháng 9",
    "Oct." : "Tháng 10",
    "Nov." : "Tháng 11",
    "Dec." : "Tháng 12",
    "Settings" : "Cài đặt",
    "Saving..." : "Đang lưu...",
    "seconds ago" : "vài giây trước",
    "No" : "Không",
    "Yes" : "Có",
    "Choose" : "Chọn",
    "Error loading file picker template: {error}" : "Lỗi khi tải mẫu tập tin picker: {error}",
    "Ok" : "Đồng ý",
    "Error loading message template: {error}" : "Lỗi khi tải mẫu thông điệp: {error}",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} tập tin xung đột"],
    "One file conflict" : "Một tập tin xung đột",
    "New Files" : "File mới",
    "Which files do you want to keep?" : "Bạn muốn tiếp tục với những tập tin nào?",
    "If you select both versions, the copied file will have a number added to its name." : "Nếu bạn chọn cả hai phiên bản, tập tin được sao chép sẽ được đánh thêm số vào tên của nó.",
    "Cancel" : "Hủy",
    "Continue" : "Tiếp tục",
    "(all selected)" : "(Tất cả các lựa chọn)",
    "({count} selected)" : "({count} được chọn)",
    "Error loading file exists template" : "Lỗi khi tải tập tin mẫu đã tồn tại",
    "Shared" : "Được chia sẻ",
    "Error" : "Lỗi",
    "Error while sharing" : "Lỗi trong quá trình chia sẻ",
    "Error while unsharing" : "Lỗi trong quá trình gỡ chia sẻ",
    "Set expiration date" : "Đặt ngày kết thúc",
    "Expiration date" : "Ngày kết thúc",
    "Edit" : "Sửa",
    "Remove" : "Xóa",
    "Password" : "Mật khẩu",
    "Name" : "Tên",
    "Save" : "Lưu",
    "Sending ..." : "Đang gởi ...",
    "Email sent" : "Email đã được gửi",
    "Email link to person" : "Liên kết email tới cá nhân",
    "Shared with you and the group {group} by {owner}" : "Đã được chia sẽ với bạn và nhóm {group} bởi {owner}",
    "Shared with you by {owner}" : "Đã được chia sẽ bởi {owner}",
    "group" : "nhóm",
    "notify by email" : "Thông báo qua email",
    "Unshare" : "Bỏ chia sẻ",
    "can share" : "có thể chia sẽ",
    "can edit" : "có thể chỉnh sửa",
    "create" : "tạo",
    "delete" : "xóa",
    "access control" : "quản lý truy cập",
    "Share" : "Chia sẻ",
    "Resharing is not allowed" : "Chia sẻ lại không được cho phép",
    "Warning" : "Cảnh báo",
    "Delete" : "Xóa",
    "Rename" : "Sửa tên",
    "The object type is not specified." : "Loại đối tượng không được chỉ định.",
    "Enter new" : "Nhập mới",
    "Add" : "Thêm",
    "Edit tags" : "Sửa thẻ",
    "Error loading dialog template: {error}" : "Lỗi khi tải mẫu hội thoại: {error}",
    "No tags selected for deletion." : "Không có thẻ nào được chọn để xóa",
    "Please reload the page." : "Vui lòng tải lại trang.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Cập nhật không thành công . Vui lòng thông báo đến <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\"> Cộng đồng ownCloud </a>.",
    "The update was successful. Redirecting you to ownCloud now." : "Cập nhật thành công .Hệ thống sẽ đưa bạn tới ownCloud.",
    "Personal" : "Cá nhân",
    "Users" : "Người dùng",
    "Apps" : "Ứng dụng",
    "Admin" : "Quản trị",
    "Help" : "Giúp đỡ",
    "Access forbidden" : "Truy cập bị cấm",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Xin chào,\n\nbáo cho bạn biết rằng %s đã chia sẽ %s với bạn.\nXem nó: %s\n\n",
    "The share will expire on %s." : "Chia sẻ này sẽ hết hiệu lực vào %s.",
    "Cheers!" : "Chúc mừng!",
    "Create an <strong>admin account</strong>" : "Tạo một <strong>tài khoản quản trị</strong>",
    "Username" : "Tên đăng nhập",
    "Data folder" : "Thư mục dữ liệu",
    "Configure the database" : "Cấu hình cơ sở dữ liệu",
    "Database user" : "Người dùng cơ sở dữ liệu",
    "Database password" : "Mật khẩu cơ sở dữ liệu",
    "Database name" : "Tên cơ sở dữ liệu",
    "Database tablespace" : "Cơ sở dữ liệu tablespace",
    "Database host" : "Database host",
    "Finish setup" : "Cài đặt hoàn tất",
    "Finishing …" : "Đang hoàn thành ...",
    "Log out" : "Đăng xuất",
    "Search" : "Tìm kiếm",
    "Server side authentication failed!" : "Xác thực phía máy chủ không thành công!",
    "Please contact your administrator." : "Vui lòng liên hệ với quản trị viên.",
    "Log in" : "Đăng nhập",
    "Alternative Logins" : "Đăng nhập khác",
    "Use the following link to reset your password: {link}" : "Dùng đường dẫn sau để khôi phục lại mật khẩu : {link}",
    "New password" : "Mật khẩu mới",
    "Reset password" : "Khôi phục mật khẩu",
    "This ownCloud instance is currently in single user mode." : "OwnCloud trong trường hợp này đang ở chế độ người dùng duy nhất.",
    "This means only administrators can use the instance." : "Điều này có nghĩa chỉ có người quản trị có thể sử dụng trong trường hợp này.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Liên hệ với người quản trị nếu lỗi này vẫn tồn tại hoặc xuất hiện bất ngờ.",
    "Thank you for your patience." : "Cảm ơn sự kiên nhẫn của bạn."
},
"nplurals=1; plural=0;");

==> owncloud-10.4.0.zip: owncloud/core/l10n/vi.js <==
OC.L10N.register(
    "core",
    {
    "Please select a file." : "Vui lòng chọn một tập tin",
    "File is too big" : "Tập tin quá lớn",
    "Invalid file provided" : "Tập tin không hợp lệ",
    "No image or file provided" : "Không có hình ảnh hoặc tập tin được cung cấp",
    "Unknown filetype" : "Không biết kiểu tập tin",
    "Invalid image" : "Hình ảnh không hợp lệ",
    "An error occurred. Please contact your admin." : "Đã xảy ra lỗi. Vui lòng liên hệ admin của bạn.",
    "No temporary profile picture available, try again" : "Ảnh cá nhân tạm thời không có giá trị, hãy thử lại",
    "No crop data provided" : "Không có dữ liệu nguồn được cung cấp",
    "No valid crop data provided" : "Dữ liệu crop không hợp lệ",
    "Crop is not square" : "Crop không phải hình vuông",
    "Could not reset password because the token is invalid" : "Không thể đặt lại mật khẩu vì mã thông báo không hợp lệ",
    "Could not reset password because the token expired" : "Không thể đặt lại mật khẩu vì mã thông báo đã hết hạn",
    "Could not reset password because the token does not match" : "Không thể đặt lại mật khẩu vì mã thông báo không khớp",
    "%s password changed successfully" : "%s mật khẩu đã được thay đổi thành công",
    "%s password reset" : "%s thiết lập lại mật khẩu",
    "Couldn't send reset email. Please contact your administrator." : "Không thể gửi email đặt lại. Vui lòng liên hệ với quản trị viên của bạn.",
    "Download / View" : "Tải về / Xem",
    "Recipients can view or download contents." : "Người nhận chỉ có thể xem hoặc tải nội dung.",
    "Download / View / Upload" : "Tải về / Xem / Tải lên",
    "Recipients can view, download, edit, delete and upload contents." : "Người nhận có thể xem, tải về, chỉnh sửa, xóa và tải lên nội dung.",
    "Preparing update" : "Chuẩn bị cập nhật",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Cảnh báo đang sửa:",
    "Repair error: " : "Lỗi sửa chữa:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Vui lòng sử dụng trình cập nhật bằng lệnh vì tính năng tự động cập nhật bị vô hiệu hóa trong config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Kiểm tra bảng %s",
    "Turned on maintenance mode" : "Bật chế độ bảo trì",
    "Turned off maintenance mode" : "Tắt chế độ bảo trì",
    "Updated database" : "Cơ sở dữ liệu đã được cập nhật",
    "Sunday" : "Chủ nhật",
    "Monday" : "Thứ 2",
    "Tuesday" : "Thứ 3",
    "Wednesday" : "Thứ 4",
    "Thursday" : "Thứ 5",
    "Friday" : "Thứ ",
    "Saturday" : "Thứ 7",
    "Sun." : "Chủ nhật",
    "Mon." : "Thứ hai",
    "Tue." : "Thứ ba",
    "Wed." : "Thứ tư",
    "Thu." : "Thứ năm",
    "Fri." : "Thứ sáu",
    "Sat." : "Thứ bảy",
    "January" : "Tháng 1",
    "February" : "Tháng 2",
    "March" : "Tháng 3",
    "April" : "Tháng 4",
    "May" : "Tháng 5",
    "June" : "Tháng 6",
    "July" : "Tháng 7",
    "August" : "Tháng 8",
    "September" : "Tháng 9",
    "October" : "Tháng 10",
    "November" : "Tháng 11",
    "December" : "Tháng 12",
    "Jan." : "Tháng 1",
    "Feb." : "Tháng 2",
    "Mar." : "Tháng 3",
    "Apr." : "Tháng 4",
    "May." : "Tháng 5",
    "Jun." : "Tháng 6",
    "Jul." : "Tháng 7",
    "Aug." : "Tháng 8",
    "Sep." : "Tháng 9",
    "Oct." : "Tháng 10",
    "Nov." : "Tháng 11",
    "Dec." : "Tháng 12",
    "Settings" : "Cài đặt",
    "Saving..." : "Đang lưu...",
    "Dismiss" : "Đóng",
    "seconds ago" : "vài giây trước",
    "No" : "Không",
    "Yes" : "Có",
    "Choose" : "Chọn",
    "Error loading file picker template: {error}" : "Lỗi khi tải mẫu tập tin picker: {error}",
    "Ok" : "Đồng ý",
    "Error loading message template: {error}" : "Lỗi khi tải mẫu thông điệp: {error}",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} tập tin xung đột"],
    "One file conflict" : "Một tập tin xung đột",
    "New Files" : "File mới",
    "Which files do you want to keep?" : "Bạn muốn tiếp tục với những tập tin nào?",
    "If you select both versions, the copied file will have a number added to its name." : "Nếu bạn chọn cả hai phiên bản, tập tin được sao chép sẽ được đánh thêm số vào tên của nó.",
    "Cancel" : "Hủy",
    "Continue" : "Tiếp tục",
    "(all selected)" : "(Tất cả các lựa chọn)",
    "({count} selected)" : "({count} được chọn)",
    "Error loading file exists template" : "Lỗi khi tải tập tin mẫu đã tồn tại",
    "Shared" : "Được chia sẻ",
    "Error" : "Lỗi",
    "Error while sharing" : "Lỗi trong quá trình chia sẻ",
    "Error while unsharing" : "Lỗi trong quá trình gỡ chia sẻ",
    "Edit" : "Sửa",
    "Remove" : "Xóa",
    "Copy to clipboard" : "Sao chép vào clipboard",
    "Anyone with the link has access to the file/folder" : "Bất cứ ai liên kết đều có quyền truy cập tệp tin/thư mục",
    "Name" : "Tên",
    "Password" : "Mật khẩu",
    "Share" : "Chia sẻ",
    "Save" : "Lưu",
    "Email link to person" : "Liên kết email tới cá nhân",
    "Shared with you and the group {group} by {owner}" : "Đã được chia sẽ với bạn và nhóm {group} bởi {owner}",
    "Shared with you by {owner}" : "Đã được chia sẽ bởi {owner}",
    "group" : "nhóm",
    "notify by email" : "Thông báo qua email",
    "Unshare" : "Bỏ chia sẻ",
    "can share" : "có thể chia sẽ",
    "can edit" : "có thể chỉnh sửa",
    "create" : "tạo",
    "change" : "thay đôi",
    "delete" : "xóa",
    "access control" : "quản lý truy cập",
    "User" : "Người dùng",
    "Group" : "N",
    "Public Links" : "Liên kết công khai",
    "Delete" : "Xóa",
    "Rename" : "Sửa tên",
    "The object type is not specified." : "Loại đối tượng không được chỉ định.",
    "Enter new" : "Nhập mới",
    "Add" : "Thêm",
    "Edit tags" : "Sửa thẻ",
    "Error loading dialog template: {error}" : "Lỗi khi tải mẫu hội thoại: {error}",
    "No tags selected for deletion." : "Không có thẻ nào được chọn để xóa",
    "Please reload the page." : "Vui lòng tải lại trang.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Cập nhật không thành công . Vui lòng thông báo đến <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\"> Cộng đồng ownCloud </a>.",
    "The update was successful. Redirecting you to ownCloud now." : "Cập nhật thành công .Hệ thống sẽ đưa bạn tới ownCloud.",
    "Personal" : "Cá nhân",
    "Users" : "Người dùng",
    "Apps" : "Ứng dụng",
    "Admin" : "Quản trị",
    "Help" : "Giúp đỡ",
    "Access forbidden" : "Truy cập bị cấm",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Xin chào,\n\nbáo cho bạn biết rằng %s đã chia sẽ %s với bạn.\nXem nó: %s\n\n",
    "The share will expire on %s." : "Chia sẻ này sẽ hết hiệu lực vào %s.",
    "Cheers!" : "Chúc mừng!",
    "Imprint" : "Đánh dấu",
    "Create an <strong>admin account</strong>" : "Tạo một <strong>tài khoản quản trị</strong>",
    "Username" : "Tên đăng nhập",
    "Data folder" : "Thư mục dữ liệu",
    "Configure the database" : "Cấu hình cơ sở dữ liệu",
    "Database user" : "Người dùng cơ sở dữ liệu",
    "Database password" : "Mật khẩu cơ sở dữ liệu",
    "Database name" : "Tên cơ sở dữ liệu",
    "Database tablespace" : "Cơ sở dữ liệu tablespace",
    "Database host" : "Database host",
    "Finish setup" : "Cài đặt hoàn tất",
    "Finishing …" : "Đang hoàn thành ...",
    "Log out" : "Đăng xuất",
    "Search" : "Tìm kiếm",
    "Server side authentication failed!" : "Xác thực phía máy chủ không thành công!",
    "Please contact your administrator." : "Vui lòng liên hệ với quản trị viên.",
    "Log in" : "Đăng nhập",
    "Alternative Logins" : "Đăng nhập khác",
    "Use the following link to reset your password: {link}" : "Dùng đường dẫn sau để khôi phục lại mật khẩu : {link}",
    "New password" : "Mật khẩu mới",
    "Reset password" : "Khôi phục mật khẩu",
    "This ownCloud instance is currently in single user mode." : "OwnCloud trong trường hợp này đang ở chế độ người dùng duy nhất.",
    "This means only administrators can use the instance." : "Điều này có nghĩa chỉ có người quản trị có thể sử dụng trong trường hợp này.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Liên hệ với người quản trị nếu lỗi này vẫn tồn tại hoặc xuất hiện bất ngờ.",
    "Thank you for your patience." : "Cảm ơn sự kiên nhẫn của bạn."
},
"nplurals=1; plural=0;");
